# Release Notes for STM32H5xx CMSIS

Copyright © 2023 STMicroelectronics

# Update History

V1.2.0 / 09-February-2024

## Main Changes

- First official release of STM32H5xx CMSIS drivers to support STM32H533xx and STM32H523xx devices
- Add bit definition for I3C_BCR register
- Add IS_DMA_PFREQ_INSTANCE macro
- Fix Ticket 163445: [FLASH][CMSIS] Wrong EDATA_STRT start sectors mask size
- Fix Ticket 163090: [FOSS-Audit] Licensing issues: Missing copyright from Arm Limited and original header not retained
- Update CubeIDE projects to be compliant with GCC12 diagnostics
- Fix Ticket 165407: [H5][GTZC][CMSIS]: wrong Flash illegal access bit definition
- Fix Ticket 147880: [STM32H5]|FLASH_HAL] Some option bytes are missing in stm32h5xx_hal_flash_ex.h
- Set FMC_SDCMR_MODE_2 bit field definition to 0x4
- Fix Ticket 162902: [GitHub] Wrong declaration of g_pfnVectors size in gcc/startup files
- Fix: Ticket 167776: [CMSIS] Missing TIM option register related definitions

V1.1.0 / 07-June-2023

## Main Changes

- Add DUA addresses constants definitions for STM32H573xx devices only
- Fix wrong definition of IS_TIM_CLOCKSOURCE_TIX_INSTANCE & IS_TIM_TISEL_INSTANCE macros
- Update possible values of the ATCKSEL field of TAMP active tamper control register and update the mask accordingly.

V1.0.0 / 10-February-2023

## Main Changes

- First official release version of bits and registers definition aligned with RM0481 and RM0492 (STM32H5 reference manuals)